Capability

Enum Capability 

pub enum Capability {
    Decrypt,
    Sign,
    Restrict,
    Unknown,
}
Key capability.

Defines for which usages is this key intended. All keys need to be either Decrypt or Sign keys. Some keys can also be Restricted keys.

Keys that are both Decrypt and Sign are called storage keys and are used to load other keys in the TPM. Restricted decryption keys will not reveal the plaintext to non-TPM code.

Restricted signing keys will sign only digests produced in the TPM. They are used mostly to sign data produced by the TPM, e.g. the attestation data.

Variants



Decrypt

Allows decryption using this key.



Sign

Allows signing using this key.



Restrict

This key is restricted.



Unknown

This is an unknown, unsupported capability.