pub enum PublicKeyBytes {
RSA(RsaPublic),
EC(EcPublic),
}Expand description
Public key bits.
For export of public keys this structure is used with one variant per one supported asymmetric algorithm.
Variants