Specification

Struct Specification 

pub struct Specification {
    pub provider: Provider,
    pub algo: AlgorithmSpec,
    pub private: Option<PrivateKeyMaterial>,
    pub capabilities: Vec<Capability>,
    pub auth: String,
}
Key details specification.

The specification of the contents of the key as well as by which provider it is managed. While this crate defines only the TPM provider other crates could define other provider types.

Fields

provider: Provider

Provider to use for the key.

algo: AlgorithmSpec

Algorithm used by the key.

private: Option<PrivateKeyMaterial>

Optional: key private bits.

capabilities: Vec<Capability>

List of key capabilities.

auth: String

Authentication value to use the key.