pub struct TpmProvider {
pub tcti: String,
pub handle: Option<u32>,
pub parent: Option<u32>,
pub private: Option<String>,
pub unique: Option<PublicKeyBytes>,
pub wrapped: Option<WrappedKey>,
pub policy: Option<String>,
}Expand description
TPM cryptographic provider.
Specifies details of the target TPM as well as several TPM-specific key properties.
Fields
tcti: StringConnection string for the provider. E.g. mssim: for the simulator or
device:/dev/tpmrm0 for a hardware device.
handle: Option<u32>Numeric handle of the key if it is persisted.
parent: Option<u32>Numeric handle of the parent of this key if the parent is persisted.
private: Option<String>Wrapped private bytes of the key.
unique: Option<PublicKeyBytes>Wrapped unique/public bytes of the key.
wrapped: Option<WrappedKey>Key has been wrapped by wrap.
policy: Option<String>Policy of key usage.